==> glib2.0_2.40.0.orig.tar.xz: glib-2.40.0/gio/kqueue/kqueue-helper.h <==
/*******************************************************************************
  Copyright (c) 2011, 2012 Dmitry Matveev <me@dmitrymatveev.co.uk>

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
*******************************************************************************/

#ifndef __KQUEUE_HELPER_H
#define __KQUEUE_HELPER_H

#include "kqueue-sub.h"
#include <gio/gfilemonitor.h>

gboolean _kh_startup        (void);
gboolean _kh_add_sub        (kqueue_sub *sub);
gboolean _kh_cancel_sub     (kqueue_sub *sub);

gboolean _kh_start_watching (kqueue_sub *sub);

void     _kh_dir_diff       (kqueue_sub *sub, GFileMonitor *monitor);

#endif /* __KQUEUE_HELPER_H */

==> glib-2.57.1.tar.xz: glib-2.57.1/gio/kqueue/kqueue-helper.h <==
/*******************************************************************************
  Copyright (c) 2011, 2012 Dmitry Matveev <me@dmitrymatveev.co.uk>

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
*******************************************************************************/

#ifndef __KQUEUE_HELPER_H
#define __KQUEUE_HELPER_H

#include <gio/glocalfilemonitor.h>
#include <gio/gfilemonitor.h>

#include "dep-list.h"

/**
 * kqueue_sub:
 * @filename: a name of the file to monitor
 * @fd: the associated file descriptor (used by kqueue)
 *
 * Represents a subscription on a file or directory.
 */
typedef struct
{
  GLocalFileMonitor   *mon;
  GFileMonitorSource  *source;
  gchar*    filename;
  int       fd;
  dep_list* deps;
  int       is_dir;
} kqueue_sub;

gboolean _kqsub_start_watching (kqueue_sub *sub);
void _kh_dir_diff    (kqueue_sub *sub);
void _km_add_missing (kqueue_sub *sub);
void _km_remove      (kqueue_sub *sub);

#endif /* __KQUEUE_HELPER_H */
